/*
 * [BagFreeDay.java]
 *
 * Summary: calculate when International Bag-Free day occurs.
 *
 * Copyright: (c) 1999-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  4.2 2008-12-03 add World AIDS day
 */
package com.mindprod.holidays;

import com.mindprod.common18.BigDate;

/**
 * calculate when International Bag-Free day occurs.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.0 2014-03-17 initial version
 * @since 2014-03-17
 */
public final class BagFreeDay extends HolInfo
    {
    /**
     * @inheritDoc
     */
    public String getAuthority()
        {
        return "http://plasticbagfreeday.org";
        }

    /**
     * @inheritDoc
     */
    public int getFirstYear( int base )
        {
        return 2014; //???
        }

    /**
     * @inheritDoc
     */
    public String getName()
        {
        return "Bag Free Day";
        }

    /**
     * @inheritDoc
     */
    public String getRule()
        {
        return "Always July 3";
        }

    /**
     * @inheritDoc
     */
    public int when( int year, boolean shift, int base )
        {
        if ( !isYearValid( year, base ) )
            {
            return BigDate.NULL_ORDINAL;
            }
        return shiftSatToFriSunToMon( BigDate.toOrdinal( year, 7, 3 ), shift );
        } // end when.
    }
