/*
 * [EarthDay.java]
 *
 * Summary: calculate when Earth day occurs.
 *
 * Copyright: (c) 1999-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  4.2 2008-12-03 add World AIDS day
 */
package com.mindprod.holidays;

import com.mindprod.common18.BigDate;

/**
 * calculate when Earth day occurs.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 4.2 2008-12-03 add World AIDS day
 * @see EarthHour
 * @since 1999
 */
public final class EarthDay extends HolInfo
    {
    /**
     * @inheritDoc
     */
    public String getAuthority()
        {
        return "http://www.earthday.net/about/about-faq.stm";
        }

    /**
     * @inheritDoc
     */
    public int getFirstYear( int base )
        {
        return 1970;
        }

    /**
     * @inheritDoc
     */
    public String getName()
        {
        return "Earth Day";
        }

    /**
     * @inheritDoc
     */
    public String getRule()
        {
        return "Always April 22, with parades on the nearest Saturday";
        }

    /**
     * @inheritDoc
     */
    public int when( int year, boolean shift, int base )
        {
        if ( !isYearValid( year, base ) )
            {
            return BigDate.NULL_ORDINAL;
            }
        return shiftSatToFriSunToMon( BigDate.toOrdinal( year, 4, 22 ), shift );
        } // end when.
    }
