/*
 * [EarthHour.java]
 *
 * Summary: calculate when Earth Hour occurs.
 *
 * Copyright: (c) 2010-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  1.0 2010-03-30 initial version
 *  1.1 2013-03-25 exception rule for 2013
 */
package com.mindprod.holidays;

import com.mindprod.common18.BigDate;

import static java.lang.System.*;

/**
 * calculate when Earth Hour occurs.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.1 2013-03-25 exception rule for 2013
 * @see EarthDay
 * @since 2010
 */
public final class EarthHour extends HolInfo
    {
    /**
     * debugging harness
     *
     * @param args not used
     */
    public static void main( String[] args )
        {
        HolInfo earthHour = new EarthHour();
        for ( int year = 2007; year < 3000; year++ )
            {
            out.println( new BigDate( earthHour.when( year ) ) );
            }
        }

    /**
     * @inheritDoc
     */
    public String getAuthority()
        {
        return "http://www.timeanddate.com/holidays/world/earth-hour#obs";
        }

    /**
     * @inheritDoc
     */
    public int getFirstYear( int base )
        {
        return 2007;
        }

    /**
     * @inheritDoc
     */
    public String getName()
        {
        return "Earth Hour";
        }

    /**
     * @inheritDoc
     */
    public String getRule()
        {
        // was 1 week earlier in 2013.
        return "Nearly always last Saturday in March, 8:30 9:30 PM local time.";
        }

    /**
     * @inheritDoc
     */
    public int when( int year, boolean shift, int base )
        {
        if ( !isYearValid( year, base ) )
            {
            return BigDate.NULL_ORDINAL;
            }
        else if ( year == 2013 )
            {
            return shiftSatToFriSunToMon( BigDate.ordinalOfnthXXXDay( 4
                    /* 4th Saturday of month */,
                    BigDate.SATURDAY,
                    year,
                    BigDate.MAR ), shift );
            }
        else
            {
            return shiftSatToFriSunToMon( BigDate.ordinalOfnthXXXDay( 5
                    /* last Saturday of month */,
                    BigDate.SATURDAY,
                    year,
                    BigDate.MAR ), shift );
            }
        }
    }
