/*
 * [PresidentsDay.java]
 *
 * Summary: calculate when Presidents' day occurs.
 *
 * Copyright: (c) 1999-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  4.2 2008-12-03 add World AIDS day
 */
package com.mindprod.holidays;

import com.mindprod.common18.BigDate;

/**
 * calculate when Presidents' day occurs.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 4.2 2008-12-03 add World AIDS day
 * @since 1999
 */
public final class PresidentsDay extends HolInfo
    {
    /**
     * @inheritDoc
     */
    public String getAuthority()
        {
        return "http://www.usis.usemb.se/Holidays/presiden.htm";
        }

    /**
     * @inheritDoc
     */
    public int getFirstYear( int base )
        {
        return 1971;
        }

    /**
     * @inheritDoc
     */
    public String getName()
        {
        return "Presidents Day";
        }

    /**
     * @inheritDoc
     */
    public String getRule()
        {
        return "Third Monday in February.\nReplaced Lincoln and Washington\u2019s birthday in 1971.";
        }

    /**
     * @inheritDoc
     */
    public int when( int year, boolean shift, int base )
        {
        if ( !isYearValid( year, base ) )
            {
            return BigDate.NULL_ORDINAL;
            }
        return BigDate.ordinalOfnthXXXDay( 3, BigDate.MONDAY, year, BigDate.FEB );
        } // end when.
    }
